pub struct BorrowedSocket<'socket> { /* private fields */ }Expand description
A borrowed socket.
This has a lifetime parameter to tie it to the lifetime of something that owns the socket.
This uses repr(transparent) and has the representation of a host socket,
so it can be used in FFI in places where a socket is passed as an argument,
it is not captured or consumed, and it never has the value
INVALID_SOCKET.
This typeโs .to_owned() implementation returns another BorrowedSocket
rather than an OwnedSocket. It just makes a trivial copy of the raw
socket, which is then borrowed under the same lifetime.
Implementations
Sourceimpl BorrowedSocket<'_>
impl BorrowedSocket<'_>
1.63.0 (const: 1.63.0) ยท Sourcepub const unsafe fn borrow_raw(socket: RawSocket) -> Self
pub const unsafe fn borrow_raw(socket: RawSocket) -> Self
Returns a BorrowedSocket holding the given raw socket.
Safety
The resource pointed to by socket must remain open for the duration of
the returned BorrowedSocket, and it must not have the value
INVALID_SOCKET.
Sourceimpl BorrowedSocket<'_>
impl BorrowedSocket<'_>
1.63.0 ยท Sourcepub fn try_clone_to_owned(&self) -> Result<OwnedSocket>
pub fn try_clone_to_owned(&self) -> Result<OwnedSocket>
Creates a new OwnedSocket instance that shares the same underlying
object as the existing BorrowedSocket instance.